<?php

namespace Drupal\wordpress_migrate\Plugin\migrate\process;

use Drupal\migrate\ProcessPluginBase;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;

// Use Drupal\migrate\MigrateSkipProcessException;.

/**
 * Provides migrate process plugin "wordpress_migrate_log_term". Will log term
 * ID, Name, Slug, Destination.
 */

/**
 * @MigrateProcessPlugin(
 *   id = "wordpress_migrate_log_term"
 * )
 */
class LogTerm extends ProcessPluginBase {

  /**
   *
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {
    $source = $row->getSource();

    // Get original values for debugging.
    $term_id = '';
    $name = '';
    $slug = '';

    if (isset($source['tag_slug'])) {
      // This is a tag.
      $term_id = $source['term_id'] ?? 'unknown';
      $name = $source['tag_name'] ?? 'unknown';
      $slug = $source['tag_slug'] ?? 'unknown';
    }
    elseif (isset($source['category_nicename'])) {
      // This is a category.
      $term_id = $source['term_id'] ?? 'unknown';
      $name = $source['cat_name'] ?? 'unknown';
      $slug = $source['category_nicename'] ?? 'unknown';
    }

    \Drupal::logger('wordpress_migrate')->debug(
          'Processing term: Term ID=@id, Name=@name, Slug=@slug, Destination=@dest, Value=@value', [
            '@id' => $term_id,
            '@name' => $name,
            '@slug' => $slug,
            '@dest' => $destination_property,
            '@value' => $value,
          ]
      );

    return $value;
  }

}
