<?php

declare(strict_types=1);

namespace Drupal\wordpress_migrate;

/**
 * Represents objects that create migrations from Wordpress.
 */
interface WordPressMigrationGeneratorInterface {

  /**
   * Creates WordPress migrations based on the given configuration.
   *
   * The migrations aren't returned, they're saved to the site and become
   * available via the site GUI and via Drush.
   *
   * @param array $configuration
   *   An associative array:
   *   - file_uri: Drupal stream wrapper of the source WordPress XML file.
   *   - group_id: ID of the MigrationGroup holding the generated migrations.
   *   - prefix: String to prefix to the IDs of generated migrations.
   *   - default_author: If present, username to author all imported content. If
   *     absent or empty, users will be imported from WordPress.
   *   - tag_vocabulary: Machine name of vocabulary to hold tags.
   *   - category_vocabulary: Machine name of vocabulary to hold categories.
   *   - [post|page]: Associative array of type-specific configuration:
   *     - type: Machine name of Drupal node bundle to hold content.
   *     - text_format: Machine name of text format for body field.
   */
  public function createMigrations(array $configuration): void;

}
